@@ -76,6 +76,19 @@ public:
     KConfigSkeleton *config() const Q_DECL_OVERRIDE;
     QList<Kerfuffle::SettingsPage*> settingsPages(QWidget *parent) const Q_DECL_OVERRIDE;
 
+    /**
+     * Validate the localFilePath() associated to this part.
+     * If the file is not valid, an error message is displayed to the user.
+     * @return Whether the localFilePath() can be loaded by the part.
+     */
+    bool isLocalFileValid();
+
+    /**
+     * Ask the user whether to overwrite @p targetFile, when creating a new archive with the same path.
+     * @return True if the file has been successfully removed upon user's will. False otherwise.
+     */
+    bool confirmAndDelete(const QString& targetFile);
+
 public slots:
     void extractSelectedFilesTo(const QString& localPath);
 
@@ -85,7 +98,8 @@ private slots:
     void slotOpenExtractedEntry(KJob*);
     void slotOpenEntry(int mode);
     void slotError(const QString& errorMessage, const QString& details);
-    void slotExtractFiles();
+    void slotExtractArchive();
+    void slotShowExtractionDialog();
     void slotExtractionDone(KJob*);
     void slotQuickExtractFiles(QAction*);
     void slotAddFiles();
@@ -94,11 +108,13 @@ private slots:
     void slotAddFilesDone(KJob*);
     void slotDeleteFiles();
     void slotDeleteFilesDone(KJob*);
+    void slotShowProperties();
     void slotShowContextMenu();
     void slotActivated(QModelIndex);
     void slotToggleInfoPanel(bool);
     void slotSaveAs();
     void updateActions();
+    void updateQuickExtractMenu(QAction *extractAction);
     void selectionChanged();
     void adjustColumns();
     void setBusyGui();
@@ -127,11 +143,13 @@ private:
     QAction *m_previewAction;
     QAction *m_openFileAction;
     QAction *m_openFileWithAction;
-    QAction *m_extractFilesAction;
+    QAction *m_extractArchiveAction;
+    QAction *m_extractAction;
     QAction *m_addFilesAction;
     QAction *m_addDirAction;
     QAction *m_deleteFilesAction;
     QAction *m_saveAsAction;
+    QAction *m_propertiesAction;
     KToggleAction *m_showInfoPanelAction;
     InfoPanel            *m_infoPanel;
     QSplitter            *m_splitter;
