@@ -43,10 +43,10 @@
 LibarchivePlugin::LibarchivePlugin(QObject *parent, const QVariantList & args)
     : ReadWriteArchiveInterface(parent, args)
     , m_archiveReadDisk(archive_read_disk_new())
+    , m_abortOperation(false)
     , m_cachedArchiveEntryCount(0)
     , m_emitNoEntries(false)
     , m_extractedFilesSize(0)
-    , m_abortOperation(false)
 {
     qCDebug(ARK) << "Initializing libarchive plugin";
     archive_read_disk_set_standard_lookup(m_archiveReadDisk.data());
@@ -216,7 +216,7 @@ bool LibarchivePlugin::copyFiles(const QVariantList& files, const QString& desti
     QString fileBeingRenamed;
 
     // Iterate through all entries in archive.
-    while (archive_read_next_header(arch.data(), &entry) == ARCHIVE_OK) {
+    while (!m_abortOperation && (archive_read_next_header(arch.data(), &entry) == ARCHIVE_OK)) {
 
         if (!extractAll && remainingFiles.isEmpty()) {
             break;
@@ -412,6 +412,8 @@ bool LibarchivePlugin::copyFiles(const QVariantList& files, const QString& desti
 
     } // While entries left to read in archive.
 
+    m_abortOperation = false;
+
     qCDebug(ARK) << "Extracted" << no_entries << "entries";
 
     return archive_read_close(arch.data()) == ARCHIVE_OK;
